<template>
  <div class="app-container">
    <div class="search_form">
      <div>
        <span class="search_title">回款台账</span>
        <el-input
            v-model="searchForm.searchText"
            style="width: 240px"
            placeholder="输入客户名称搜索"
            @change="handleQuery"
            clearable
            :prefix-icon="Search"
        />
        <el-button type="primary" @click="handleQuery" style="margin-left: 10px">搜索</el-button>
      </div>
    </div>
    <div style="display: flex">
      <div class="table_list">
        <el-table :data="tableData" border v-loading="tableLoading"
                  :row-key="row => row.id"
                  show-summary
                  :summary-method="summarizeMainTable"
                  @row-click = "rowClickMethod"
                  height="calc(100vh - 18.5em)">
          <el-table-column align="center" label="序号" type="index" width="60" />
          <el-table-column label="客户名称" prop="customerName" show-overflow-tooltip/>
          <el-table-column label="开票金额" prop="invoiceTotal" show-overflow-tooltip/>
          <el-table-column label="回款金额" prop="receiptPaymentAmount" show-overflow-tooltip/>
          <el-table-column label="未回款金额" prop="unReceiptPaymentAmount" show-overflow-tooltip/>
        </el-table>
        <pagination v-show="total > 0" :total="total" layout="total, sizes, prev, pager, next, jumper" :page="page.current"
                    :limit="page.size" @pagination="paginationChange" />
      </div>
      <div class="table_list">
        <el-table :data="receiptRecord" border
                  :row-key="row => row.id"
                  show-summary
                  :summary-method="summarizeMainTable"
                  height="calc(100vh - 18.5em)">
          <el-table-column align="center" label="序号" type="index" width="60" />
          <el-table-column label="发生日期" prop="receiptPaymentDate" show-overflow-tooltip/>
          <el-table-column label="回款金额" prop="receiptPaymentAmount" show-overflow-tooltip/>
          <el-table-column label="待收金额" prop="noReceiptAmount" show-overflow-tooltip/>
          <el-table-column label="应收金额" prop="invoiceTotal" show-overflow-tooltip/>
        </el-table>
        <pagination v-show="recordTotal > 0" :total="recordTotal" layout="total, sizes, prev, pager, next, jumper" :page="recordPage.current"
                    :limit="recordPage.size" @pagination="recordPaginationChange" />
      </div>
    </div>

  </div>
</template>

<script setup>
import { ref } from 'vue'
import {
  invoiceLedgerSalesAccount,
} from "../../../api/salesManagement/invoiceLedger.js";
import {
  receiptPaymentListPage
} from "../../../api/salesManagement/receiptPayment.js";
import Pagination from "../../../components/PIMTable/Pagination.vue";

const tableData = ref([])
const receiptRecord = ref([])
const tableLoading = ref(false)
const page = reactive({
  current: 1,
  size: 10,
})
const recordPage = reactive({
  current: 1,
  size: 10,
})
const total = ref(0)
const recordTotal = ref(0)
const data = reactive({
  searchForm: {
    searchText: '',
    invoiceDate:''
  }
})
const customerId = ref('')
const { searchForm } = toRefs(data)
// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
  page.current = 1
  getList()
}
const paginationChange = (obj) => {
  console.log('paginationChange', current,limit)
  page.current = obj.page;
  page.size = obj.limit;
  getList()
}
const getList = () => {
  tableLoading.value = true
  invoiceLedgerSalesAccount({...searchForm.value, ...page}).then(res => {
    tableLoading.value = false
    tableData.value = res.data.records;
    total.value = res.data.total;
    if(tableData.value.length > 0) {
      recordPage.current = 1
      customerId.value = tableData.value[0].id
      receiptPaymentList(customerId.value);
    }
  })
}
// 主表合计方法
const summarizeMainTable = (param) => {
  const { columns, data } = param;
  const sums = [];
  columns.forEach((column, index) => {
    if (index === 0) {
      sums[index] = '合计';
      return;
    }
    const prop = column.property;
    if (['invoiceAmount','receiptPaymentAmount','unReceiptPaymentAmount'].includes(prop)) {
      const values = data.map(item => Number(item[prop]));
      if (!values.every(value => isNaN(value))) {
        sums[index] = values.reduce((acc, val) => (!isNaN(val) ? acc + val : acc), 0);
      } else {
        sums[index] = '';
      }
    } else {
      sums[index] = '';
    }
  })
  return sums;
};

const receiptPaymentList = (id) => {
  const param = {
    customerId:id,
    current: recordPage.current,
    size: recordPage.size,
  }
  console.log('param', param)
  receiptPaymentListPage(param).then(res => {
    receiptRecord.value = res.data.records;
    recordTotal.value = res.data.total;

  })
}

// 汇款记录列表分页
const recordPaginationChange = (obj) => {
  console.log('recordPaginationChange', obj );
  recordPage.current = obj.page;
  recordPage.size = obj.limit;
  console.log('recordPage',recordPage)
  receiptPaymentList(customerId.value);
}

const rowClickMethod = (row) => {
  customerId.value = row.id;
  receiptPaymentList(customerId.value);
}


getList()
</script>

<style scoped lang="scss">

.table_list {
  width: 50%;
}

</style>
